"""aligo"""
from .types import *
from .request import *
from .response import *
from .core import *
from .apis import *

__title__ = 'aligo'
__description__ = 'apis lib for aliyundrive.'
__url__ = 'https://github.com/foyoux/aligo'
__version__ = '1.1.10'
__author__ = 'foyou'
__author_email__ = 'yimi.0822@qq.com'
__license__ = 'Apache 2.0'
__copyright__ = f'Copyright 2021 {__author__}'
__ide__ = 'PyCharm - https://www.jetbrains.com/pycharm/'
